import logging

from django.contrib import messages
from django.shortcuts import render
from django.views.generic import TemplateView

from core.models import VoucherEntry

from .mixins import ConferenceLoginRequiredMixin

logger = logging.getLogger(__name__)
MAX_ROWS = 42


class VouchersView(ConferenceLoginRequiredMixin, TemplateView):
    permission_required = ['core.assembly_team']
    template_name = 'backoffice/vouchers-list.html'

    def get_context_data(self, *args, **kwargs):
        ctx = super().get_context_data(*args, **kwargs)
        ctx['active_page'] = 'vouchers'
        ctx['object_list'] = None
        ctx['myconf'] = self.request.method == 'GET' or 'myconf' in self.request.POST

        return ctx

    def post(self, *args, **kwargs):
        search_term = self.request.POST.get('search', '')

        direct_matches = []
        qs = VoucherEntry.objects.filter(content__icontains=search_term)
        results = list(direct_matches) + list(qs[: MAX_ROWS + 1])
        more_results = len(results) > MAX_ROWS

        if more_results:
            messages.warning(self.request, f'Ausgabe auf {MAX_ROWS} Einträge beschränkt!')
            results = results[:MAX_ROWS]

        ctx = self.get_context_data()
        ctx['object_list'] = results
        ctx['search_term'] = search_term
        ctx['more_results'] = more_results
        return render(self.request, self.template_name, ctx)
