# Generated by Django 4.2.8 on 2023-12-20 01:23

from django.apps.registry import apps as global_apps
from django.db import migrations
from django.contrib.contenttypes.management import create_contenttypes

from core.models import Room as RoomModel

fields = [
    'id',
    'name',
    'slug',
    'description',
    'description_de',
    'description_en',
    'description_html',
    'description_html_de',
    'description_html_en',
    'assembly_id',
    'conference_id',
    'blocked',
]


def forwards_func(apps, schema_editor):
    core_app_config = global_apps.get_app_config('core')
    create_contenttypes(core_app_config)
    ContentType = apps.get_model('contenttypes', 'ContentType')
    Project = apps.get_model('core', 'Project')
    Room = apps.get_model('core', 'Room')
    RoomLink = apps.get_model('core', 'RoomLink')
    Link = apps.get_model('core', 'Link')
    room_fields = [*fields, 'blocked']
    project_content_type = None

    for room in Room.objects.filter(room_type='project').values(*room_fields):
        if room['description'] is None:
            room['description'] = ''
        is_public = True
        project = Project.objects.create(**room, is_public=is_public)
        project_content_type = project_content_type if project_content_type else ContentType.objects.get(app_label='core', model='project')
        links = RoomLink.objects.filter(room_id=room['id']).values()
        for link_data_dict in links if links else []:
            for key in ['id', 'room_id']:
                link_data_dict.pop(key)
            Link.objects.create(
                **link_data_dict,
                content_type=project_content_type,
                object_id=project.id,
            )
        Room.objects.filter(id=room['id']).delete()


def reverse_func(apps, schema_editor):
    core_app_config = global_apps.get_app_config('core')
    create_contenttypes(core_app_config)
    ContentType = apps.get_model('contenttypes', 'ContentType')
    Project = apps.get_model('core', 'Project')
    Room = apps.get_model('core', 'Room')
    project_fields = [*fields]
    RoomLink = apps.get_model('core', 'RoomLink')
    Link = apps.get_model('core', 'Link')
    project_content_type = None

    for project in Project.objects.all().values(*project_fields):
        project_content_type = project_content_type if project_content_type else ContentType.objects.get(app_label='core', model='project')
        if project['assembly_id'] is None:
            Project.objects.filter(id=project['id']).delete()
            continue
        room, _ = Room.objects.get_or_create(
            **project,
            room_type=RoomModel.RoomType.PROJECT,
        )
        links = Link.objects.filter(object_id=project['id'], content_type=project_content_type).values()
        for link_data_dict in links if links else []:
            for key in ['id', 'content_type_id', 'object_id']:
                link_data_dict.pop(key)
            RoomLink.objects.create(
                **link_data_dict,
                room_id=room.id,
            )


class Migration(migrations.Migration):
    dependencies = [
        ("contenttypes", "0002_remove_content_type_name"),
        ('core', '0139_favorite_link_project_remove_roomlink_send_token_and_more'),
    ]

    operations = [
        migrations.RunPython(forwards_func, reverse_func),
    ]
