// No ES modules used. Wrap into a closure to avoid collisions.
(function () {
  // Wait until document is loaded
  const docReady = (callback) => {
    if (document.readyState != "loading") callback();
    else document.addEventListener("DOMContentLoaded", callback);
  };

  // Defined in _calendar.scss
  const scrollOffset = -5;

  /**
   * Tries to get the Fahrplan Element.
   * This may be something different depending on whether it shows the public or regular Fahrplan view.
   */
  const getFahrplanElement = () => {
    return document.querySelector(".hub-fahrplan__pub-box") ?? document.getElementById("hub-fahrplan-calendar");
  };

  docReady(() => {
    const fahrplanElement = getFahrplanElement();

    if (fahrplanElement === null) {
      // Nothing to do, if there is no Fahrplan
      return;
    }

    const roomNames = document.querySelectorAll(".hub-calendar__column-title");

    /**
     * When scrolling, keep room names always on top of the columns.
     *
     * @param {Event} event
     */
    const handleScroll = (event) => {
      // Keep room names always on top of the columns
      const scrollPosition = event.target.scrollTop;
      const roomNameTop = `${scrollPosition + scrollOffset}px`;

      roomNames.forEach((roomName) => {
        roomName.style.top = roomNameTop;
      });
    };

    fahrplanElement.addEventListener("scroll", handleScroll);
  });
})();
